@@ -21,26 +21,28 @@
 #include <math.h>
 #include <stdlib.h>
 
-#include <QApplication>
-#include <QFrame>
-#include <QGridLayout>
-#include <QHBoxLayout>
-#include <QResizeEvent>
-#include <QScrollBar>
-#include <QtGlobal>
-#include <QWheelEvent>
+#include <QtGui/QApplication>
+#include <QtGui/QFrame>
+#include <QtGui/QGridLayout>
+#include <QtGui/QHBoxLayout>
+#include <QtGui/QResizeEvent>
+#include <QtGui/QScrollBar>
+#include <QtCore/QtGlobal>
+#include <QtGui/QWheelEvent>
 
 #include <klocale.h>
 
 #include "libkwave/ApplicationContext.h"
 #include "libkwave/CodecManager.h"
-#include "libkwave/KwaveDrag.h"
-#include "libkwave/KwaveFileDrag.h"
+#include "libkwave/Drag.h"
+#include "libkwave/FileDrag.h"
+#include "libkwave/FileInfo.h"
 #include "libkwave/Label.h"
 #include "libkwave/LabelList.h"
 #include "libkwave/MessageBox.h"
 #include "libkwave/Parser.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
 
 #include "libgui/LabelPropertiesWidget.h"
@@ -52,7 +54,7 @@
 /**
  * useful macro for command parsing
  */
-#define CASE_COMMAND(x) } else if (parser.command() == x) {
+#define CASE_COMMAND(x) } else if (parser.command() == _(x)) {
 
 /**
  * Limits the zoom to a minimum number of samples visible in one
@@ -67,7 +69,8 @@
 #define DEFAULT_DISPLAY_TIME (5 * 60.0)
 
 //***************************************************************************
-MainWidget::MainWidget(QWidget *parent, Kwave::ApplicationContext &context)
+Kwave::MainWidget::MainWidget(QWidget *parent,
+			      Kwave::ApplicationContext &context)
     :QWidget(parent), m_context(context), m_upper_dock(), m_lower_dock(),
      m_view_port(this),
      m_signal_widget(&m_view_port, context, &m_upper_dock, &m_lower_dock),
@@ -79,7 +82,7 @@ MainWidget::MainWidget(QWidget *parent, Kwave::ApplicationContext &context)
 
     setAcceptDrops(true); // enable drag&drop
 
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return;
 
@@ -133,7 +136,7 @@ MainWidget::MainWidget(QWidget *parent, Kwave::ApplicationContext &context)
 
     // -- overview widget --
 
-    m_overview = new OverViewWidget(*signal_manager, this);
+    m_overview = new Kwave::OverViewWidget(*signal_manager, this);
     Q_ASSERT(m_overview);
     if (!m_overview) return;
     m_overview->setMinimumHeight(m_overview->sizeHint().height());
@@ -161,7 +164,7 @@ MainWidget::MainWidget(QWidget *parent, Kwave::ApplicationContext &context)
 
     // -- playback position update --
 
-    PlaybackController &playback = signal_manager->playbackController();
+    Kwave::PlaybackController &playback = signal_manager->playbackController();
     connect(&playback, SIGNAL(sigPlaybackPos(sample_index_t)),
 	m_overview, SLOT(playbackPositionChanged(sample_index_t)));
     connect(&playback, SIGNAL(sigPlaybackStopped()),
@@ -193,13 +196,13 @@ MainWidget::MainWidget(QWidget *parent, Kwave::ApplicationContext &context)
 }
 
 //***************************************************************************
-bool MainWidget::isOK()
+bool Kwave::MainWidget::isOK()
 {
     return (m_vertical_scrollbar && m_horizontal_scrollbar && m_overview);
 }
 
 //***************************************************************************
-MainWidget::~MainWidget()
+Kwave::MainWidget::~MainWidget()
 {
     Kwave::PluginManager *plugin_manager = m_context.pluginManager();
     Q_ASSERT(plugin_manager);
@@ -207,40 +210,42 @@ MainWidget::~MainWidget()
 }
 
 //***************************************************************************
-void MainWidget::resizeEvent(QResizeEvent *event)
+void Kwave::MainWidget::resizeEvent(QResizeEvent *event)
 {
     Q_UNUSED(event);
     resizeViewPort();
 }
 
 //***************************************************************************
-void MainWidget::dragEnterEvent(QDragEnterEvent *event)
+void Kwave::MainWidget::dragEnterEvent(QDragEnterEvent *event)
 {
     if (!event) return;
     if ((event->proposedAction() != Qt::MoveAction) &&
         (event->proposedAction() != Qt::CopyAction))
         return; /* unsupported action */
 
-    if (KwaveFileDrag::canDecode(event->mimeData()))
+    if (Kwave::FileDrag::canDecode(event->mimeData()))
 	event->acceptProposedAction();
 }
 
 
 //***************************************************************************
-void MainWidget::dropEvent(QDropEvent *event)
+void Kwave::MainWidget::dropEvent(QDropEvent *event)
 {
     if (!event) return;
     if (!event->mimeData()) return;
 
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return;
 
-    if (signal_manager->isEmpty() && KwaveDrag::canDecode(event->mimeData())) {
+    if (signal_manager->isEmpty() &&
+	Kwave::Drag::canDecode(event->mimeData()))
+    {
 	sample_index_t pos = m_offset + pixels2samples(event->pos().x());
 	sample_index_t len = 0;
 
-	if ((len = KwaveDrag::decode(this, event->mimeData(),
+	if ((len = Kwave::Drag::decode(this, event->mimeData(),
 	    *signal_manager, pos)))
 	{
 	    // set selection to the new area where the drop was done
@@ -254,15 +259,15 @@ void MainWidget::dropEvent(QDropEvent *event)
 	bool first = true;
 	foreach (QUrl url, event->mimeData()->urls()) {
 	    QString filename = url.toLocalFile();
-	    QString mimetype = CodecManager::whatContains(filename);
-	    if (CodecManager::canDecode(mimetype)) {
+	    QString mimetype = Kwave::CodecManager::whatContains(filename);
+	    if (Kwave::CodecManager::canDecode(mimetype)) {
 		if (first) {
 		    // first dropped URL -> open in this window
-		    emit sigCommand("open(" + filename + ")");
+		    emit sigCommand(_("open(") + filename + _(")"));
 		    first = false;
 		} else {
 		    // all others -> open a new window
-		    emit sigCommand("newwindow(" + filename + ")");
+		    emit sigCommand(_("newwindow(") + filename + _(")"));
 		}
 	    }
 	}
@@ -272,7 +277,7 @@ void MainWidget::dropEvent(QDropEvent *event)
 }
 
 //***************************************************************************
-void MainWidget::wheelEvent(QWheelEvent *event)
+void Kwave::MainWidget::wheelEvent(QWheelEvent *event)
 {
     if (!event || !m_overview) return;
 
@@ -289,26 +294,26 @@ void MainWidget::wheelEvent(QWheelEvent *event)
 	case Qt::NoModifier: {
 	    // no modifier + <WheelUp/Down> => scroll left/right
 	    if (event->delta() > 0)
-		executeCommand("view:scroll_left()");
+		executeCommand(_("view:scroll_left()"));
 	    else if (event->delta() < 0)
-		executeCommand("view:scroll_right()");
+		executeCommand(_("view:scroll_right()"));
 	    event->accept();
 	    break;
 	}
 	case Qt::ShiftModifier:
 	    // <Shift> + <WheelUp/Down> => page up/down
 	    if (event->delta() > 0)
-		executeCommand("view:scroll_prev()");
+		executeCommand(_("view:scroll_prev()"));
 	    else if (event->delta() < 0)
-		executeCommand("view:scroll_next()");
+		executeCommand(_("view:scroll_next()"));
 	    event->accept();
 	    break;
 	case Qt::ControlModifier:
 	    // <Ctrl> + <WheelUp/Down> => zoom in/out
 	    if (event->delta() > 0)
-		executeCommand("view:zoom_in()");
+		executeCommand(_("view:zoom_in()"));
 	    else if (event->delta() < 0)
-		executeCommand("view:zoom_out()");
+		executeCommand(_("view:zoom_out()"));
 	    event->accept();
 	    break;
 	default:
@@ -317,13 +322,14 @@ void MainWidget::wheelEvent(QWheelEvent *event)
 }
 
 //***************************************************************************
-void MainWidget::verticalScrollBarMoved(int newval)
+void Kwave::MainWidget::verticalScrollBarMoved(int newval)
 {
     m_signal_widget.move(0, -newval); // move the signal views
 }
 
 //***************************************************************************
-void MainWidget::slotTrackInserted(unsigned int index, Kwave::Track *track)
+void Kwave::MainWidget::slotTrackInserted(unsigned int index,
+                                          Kwave::Track *track)
 {
 //     qDebug("MainWidget::slotTrackInserted(%u, %p)",
 // 	   index, static_cast<void *>(track));
@@ -331,7 +337,7 @@ void MainWidget::slotTrackInserted(unsigned int index, Kwave::Track *track)
     Q_UNUSED(track);
 
     // when the first track has been inserted, set some reasonable zoom
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     bool first_track = (signal_manager && (signal_manager->tracks() == 1));
 
     resizeViewPort();
@@ -340,7 +346,7 @@ void MainWidget::slotTrackInserted(unsigned int index, Kwave::Track *track)
 }
 
 //***************************************************************************
-void MainWidget::slotTrackDeleted(unsigned int index)
+void Kwave::MainWidget::slotTrackDeleted(unsigned int index)
 {
 //     qDebug("MainWidget::slotTrackDeleted(%u)", index);
     Q_UNUSED(index);
@@ -350,20 +356,20 @@ void MainWidget::slotTrackDeleted(unsigned int index)
 }
 
 //***************************************************************************
-double MainWidget::zoom() const
+double Kwave::MainWidget::zoom() const
 {
     return m_zoom;
 }
 
 //***************************************************************************
-int MainWidget::executeCommand(const QString &command)
+int Kwave::MainWidget::executeCommand(const QString &command)
 {
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return -EINVAL;
     if (!command.length()) return -EINVAL;
 
-    Parser parser(command);
+    Kwave::Parser parser(command);
     const sample_index_t visible_samples = displaySamples();
     const sample_index_t signal_length   = signal_manager->length();
 
@@ -406,7 +412,7 @@ int MainWidget::executeCommand(const QString &command)
 	          (m_offset - visible_samples) : 0);
     CASE_COMMAND("view:scroll_next_label")
 	sample_index_t ofs =
-	    LabelList(signal_manager->metaData()).nextLabelRight(
+	    Kwave::LabelList(signal_manager->metaData()).nextLabelRight(
 		m_offset + (visible_samples / 2));
 	if (ofs > signal_length)
 	    ofs = signal_length - 1;
@@ -414,7 +420,7 @@ int MainWidget::executeCommand(const QString &command)
 	          (ofs - (visible_samples / 2)) : 0);
     CASE_COMMAND("view:scroll_prev_label")
 	sample_index_t ofs =
-	    LabelList(signal_manager->metaData()).nextLabelLeft(
+	    Kwave::LabelList(signal_manager->metaData()).nextLabelLeft(
 		m_offset + (visible_samples / 2));
 	setOffset((ofs > (visible_samples / 2)) ?
 	          (ofs - (visible_samples / 2)) : 0);
@@ -451,14 +457,14 @@ int MainWidget::executeCommand(const QString &command)
 	addLabel(pos, description);
     CASE_COMMAND("edit_label")
 	int index = parser.toInt();
-	LabelList labels(signal_manager->metaData());
+	Kwave::LabelList labels(signal_manager->metaData());
 	if ((index >= labels.count()) || (index < 0))
 	    return -EINVAL;
-	Label label = labels.at(index);
+	Kwave::Label label = labels.at(index);
 	labelProperties(label);
 
 //    CASE_COMMAND("chooselabel")
-//	Parser parser(command);
+//	Kwave::Parser parser(command);
 //	markertype = globals.markertypes.at(parser.toInt());
 //    CASE_COMMAND("amptolabel")
 //	markSignal(command);
@@ -484,7 +490,7 @@ int MainWidget::executeCommand(const QString &command)
 }
 
 //***************************************************************************
-void MainWidget::resizeViewPort()
+void Kwave::MainWidget::resizeViewPort()
 {
     const int old_h = m_signal_widget.height();
     const int old_w = m_signal_widget.width();
@@ -512,7 +518,6 @@ void MainWidget::resizeViewPort()
 	// hide the vertical scrollbar
 	if (vertical_scrollbar_visible) {
 	    m_vertical_scrollbar->setShown(false);
-	    vertical_scrollbar_visible = false;
 	    w += b;
 	    m_signal_widget.move(0, 0);
 	    // qDebug("MainWidget::resizeViewPort(): hiding scrollbar");
@@ -529,7 +534,6 @@ void MainWidget::resizeViewPort()
 	    m_vertical_scrollbar->setFixedWidth(b);
 	    m_vertical_scrollbar->setValue(0);
 	    m_vertical_scrollbar->setShown(true);
-	    vertical_scrollbar_visible = true;
 	    w -= b;
 	    // qDebug("MainWidget::resizeViewPort(): showing scrollbar");
 	}
@@ -567,7 +571,7 @@ void MainWidget::resizeViewPort()
 }
 
 //***************************************************************************
-void MainWidget::refreshHorizontalScrollBar()
+void Kwave::MainWidget::refreshHorizontalScrollBar()
 {
     if (!m_horizontal_scrollbar || !m_context.signalManager()) return;
 
@@ -624,7 +628,7 @@ void MainWidget::refreshHorizontalScrollBar()
 }
 
 //***************************************************************************
-void MainWidget::horizontalScrollBarMoved(int newval)
+void Kwave::MainWidget::horizontalScrollBarMoved(int newval)
 {
     // new offset = pos * f
     const int f = qMax(1U, SAMPLE_INDEX_MAX / INT_MAX);
@@ -633,9 +637,9 @@ void MainWidget::horizontalScrollBarMoved(int newval)
 }
 
 //***************************************************************************
-void MainWidget::updateViewRange()
+void Kwave::MainWidget::updateViewRange()
 {
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     sample_index_t total = (signal_manager) ? signal_manager->length() : 0;
 
     // forward the zoom and offset to the signal widget and overview
@@ -645,9 +649,9 @@ void MainWidget::updateViewRange()
 }
 
 //***************************************************************************
-sample_index_t MainWidget::ms2samples(double ms)
+sample_index_t Kwave::MainWidget::ms2samples(double ms)
 {
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return 0;
 
@@ -656,46 +660,56 @@ sample_index_t MainWidget::ms2samples(double ms)
 }
 
 //***************************************************************************
-sample_index_t MainWidget::pixels2samples(unsigned int pixels) const
+sample_index_t Kwave::MainWidget::pixels2samples(unsigned int pixels) const
 {
-    if ((pixels <= 0) || (m_zoom <= 0.0)) return 0;
+    if ((pixels == 0) || (m_zoom <= 0.0)) return 0;
 
     return static_cast<sample_index_t>(static_cast<double>(pixels) * m_zoom);
 }
 
 //***************************************************************************
-int MainWidget::samples2pixels(sample_index_t samples) const
+int Kwave::MainWidget::samples2pixels(sample_index_t samples) const
 {
     if (m_zoom == 0.0) return 0;
     return static_cast<int>(rint(static_cast<double>(samples) / m_zoom));
 }
 
 //***************************************************************************
-int MainWidget::displayWidth() const
+int Kwave::MainWidget::displayWidth() const
 {
     return m_width;
 }
 
 //***************************************************************************
-sample_index_t MainWidget::displaySamples() const
+sample_index_t Kwave::MainWidget::displaySamples() const
 {
     return pixels2samples(m_width - 1) + 1;
 }
 
 //***************************************************************************
-double MainWidget::fullZoom() const
+double Kwave::MainWidget::fullZoom() const
 {
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return 0.0;
     if (signal_manager->isEmpty()) return 0.0;    // no zoom if no signal
 
     sample_index_t length = signal_manager->length();
     if (!length) {
-        // no length: streaming mode -> start with a default
-        // zoom, use five minutes (just guessed)
-        length = static_cast<sample_index_t>(ceil(DEFAULT_DISPLAY_TIME *
-	    signal_manager->rate()));
+	// no length: streaming mode -> try to use "estimated length"
+	// and add some extra, 10% should be ok
+	Kwave::FileInfo info(signal_manager->metaData());
+	if (info.contains(Kwave::INF_ESTIMATED_LENGTH)) {
+	    // estimated length in samples
+	    length = info.get(Kwave::INF_ESTIMATED_LENGTH).toULongLong();
+	    length += length / 10;
+	}
+	if (!length) {
+	    // fallback: start with some default zoom,
+	    // use five minutes (just guessed)
+	    length = static_cast<sample_index_t>(ceil(DEFAULT_DISPLAY_TIME *
+		signal_manager->rate()));
+	}
     }
 
     // example: width = 100 [pixels] and length = 3 [samples]
@@ -715,7 +729,7 @@ double MainWidget::fullZoom() const
 }
 
 //***************************************************************************
-void MainWidget::fixZoomAndOffset(double zoom, sample_index_t offset)
+void Kwave::MainWidget::fixZoomAndOffset(double zoom, sample_index_t offset)
 {
     double max_zoom;
     double min_zoom;
@@ -727,7 +741,7 @@ void MainWidget::fixZoomAndOffset(double zoom, sample_index_t offset)
     m_zoom   = zoom;
     m_offset = offset;
 
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return;
     if (!m_width) return;
@@ -783,19 +797,19 @@ void MainWidget::fixZoomAndOffset(double zoom, sample_index_t offset)
 }
 
 //***************************************************************************
-void MainWidget::setZoom(double new_zoom)
+void Kwave::MainWidget::setZoom(double new_zoom)
 {
     fixZoomAndOffset(new_zoom, m_offset);
 }
 
 //***************************************************************************
-void MainWidget::setOffset(sample_index_t new_offset)
+void Kwave::MainWidget::setOffset(sample_index_t new_offset)
 {
     fixZoomAndOffset(m_zoom, new_offset);
 }
 
 //***************************************************************************
-void MainWidget::scrollTo(sample_index_t pos)
+void Kwave::MainWidget::scrollTo(sample_index_t pos)
 {
     sample_index_t visible = displaySamples();
 
@@ -816,9 +830,9 @@ void MainWidget::scrollTo(sample_index_t pos)
 }
 
 //***************************************************************************
-void MainWidget::zoomSelection()
+void Kwave::MainWidget::zoomSelection()
 {
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return;
 
@@ -832,13 +846,13 @@ void MainWidget::zoomSelection()
 }
 
 //***************************************************************************
-void MainWidget::zoomAll()
+void Kwave::MainWidget::zoomAll()
 {
     setZoom(fullZoom());
 }
 
 //***************************************************************************
-void MainWidget::zoomNormal()
+void Kwave::MainWidget::zoomNormal()
 {
     const sample_index_t shift1 = m_width / 2;
     const sample_index_t shift2 = displaySamples() / 2;
@@ -848,7 +862,7 @@ void MainWidget::zoomNormal()
 }
 
 //***************************************************************************
-void MainWidget::zoomIn()
+void Kwave::MainWidget::zoomIn()
 {
     const sample_index_t shift = displaySamples() / 3;
     m_offset = (m_offset + shift >= m_offset) ? (m_offset + shift) : -shift;
@@ -856,7 +870,7 @@ void MainWidget::zoomIn()
 }
 
 //***************************************************************************
-void MainWidget::zoomOut()
+void Kwave::MainWidget::zoomOut()
 {
     const sample_index_t shift = displaySamples();
     m_offset = (m_offset > shift) ? (m_offset - shift) : 0;
@@ -864,16 +878,16 @@ void MainWidget::zoomOut()
 }
 
 //***************************************************************************
-void MainWidget::addLabel(sample_index_t pos, const QString &description)
+void Kwave::MainWidget::addLabel(sample_index_t pos, const QString &description)
 {
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return;
 
-    UndoTransactionGuard undo(*signal_manager, i18n("Add Label"));
+    Kwave::UndoTransactionGuard undo(*signal_manager, i18n("Add Label"));
 
     // add a new label, with undo
-    Label label = signal_manager->addLabel(pos, description);
+    Kwave::Label label = signal_manager->addLabel(pos, description);
     if (label.isNull()) {
 	signal_manager->abortUndoTransaction();
 	return;
@@ -903,8 +917,8 @@ void MainWidget::addLabel(sample_index_t pos, const QString &description)
 // //	FILE *out;
 // //	out = fopen (name.local8Bit(), "w");
 // //
-// //	Parser parser (typestring);
-// //	Label *tmp;
+// //	Kwave::Parser parser (typestring);
+// //	Kwave::Label *tmp;
 // //	LabelType *act;
 // //
 // //	const char *actstring = parser.getFirstParam();
@@ -938,9 +952,9 @@ void MainWidget::addLabel(sample_index_t pos, const QString &description)
 // //}
 
 //***************************************************************************
-bool MainWidget::labelProperties(Label &label)
+bool Kwave::MainWidget::labelProperties(Kwave::Label &label)
 {
-    SignalManager *signal_manager = m_context.signalManager();
+    Kwave::SignalManager *signal_manager = m_context.signalManager();
     Q_ASSERT(signal_manager);
     if (!signal_manager) return false;
 
@@ -959,7 +973,8 @@ bool MainWidget::labelProperties(Label &label)
     int old_index = -1;
     while (true) {
 	// create and prepare the dialog
-	LabelPropertiesWidget *dlg = new LabelPropertiesWidget(this);
+	Kwave::LabelPropertiesWidget *dlg =
+	    new Kwave::LabelPropertiesWidget(this);
 	Q_ASSERT(dlg);
 	if (!dlg) return false;
 	dlg->setLabelIndex(index);
@@ -991,7 +1006,7 @@ bool MainWidget::labelProperties(Label &label)
 		"Do you want to replace it?"));
 	    if (res == KMessageBox::Yes) {
 		// delete the label at the target position (with undo)
-		Label old = signal_manager->findLabel(new_pos);
+		Kwave::Label old = signal_manager->findLabel(new_pos);
 		old_index = signal_manager->labelIndex(old);
 		break;
 	    }
@@ -1014,7 +1029,7 @@ bool MainWidget::labelProperties(Label &label)
 	if ((new_name == label.name()) && (new_pos == label.pos()))
 	    return true;
 
-	UndoTransactionGuard undo(*signal_manager, i18n("Modify Label"));
+	Kwave::UndoTransactionGuard undo(*signal_manager, i18n("Modify Label"));
 
 	// if there is a label at the target position, remove it first
 	if (old_index >= 0) {
@@ -1054,7 +1069,7 @@ bool MainWidget::labelProperties(Label &label)
 // //	    selectMarkers (dialog->getCommand());
 // //
 // //	    LabelType *act;
-// //	    Label *tmp;
+// //	    Kwave::Label *tmp;
 // //	    int last = 0;
 // //	    int rate = signalmanage->getRate ();
 // //
@@ -1104,9 +1119,9 @@ bool MainWidget::labelProperties(Label &label)
 // //void MainWidget::markSignal (const char *str)
 // //{
 // //    if (signalmanage) {
-// //	Label *newmark;
+// //	Kwave::Label *newmark;
 // //
-// //	Parser parser (str);
+// //	Kwave::Parser parser (str);
 // //
 // //	int level = (int) (parser.toDouble() / 100 * (1 << 23));
 // //
@@ -1125,7 +1140,7 @@ bool MainWidget::labelProperties(Label &label)
 // //	if (dialog && start && stop) {
 // //	    dialog->show();
 // //
-// //	    newmark = new Label(0, start);     //generate initial Label
+// //	    newmark = new Kwave::Label(0, start);     //generate initial Kwave::Label
 // //
 // //	    labels->inSort (newmark);
 // //
@@ -1136,11 +1151,11 @@ bool MainWidget::labelProperties(Label &label)
 // //
 // //		    if (i - j > time) {
 // //			//insert labels...
-// //			newmark = new Label(i, start);
+// //			newmark = new Kwave::Label(i, start);
 // //			labels->inSort (newmark);
 // //
 // //			if (start != stop) {
-// //			    newmark = new Label(j, stop);
+// //			    newmark = new Kwave::Label(j, stop);
 // //			    labels->inSort (newmark);
 // //			}
 // //		    }
@@ -1148,7 +1163,7 @@ bool MainWidget::labelProperties(Label &label)
 // //		dialog->setProgress (i);
 // //	    }
 // //
-// //	    newmark = new Label(len - 1, stop);
+// //	    newmark = new Kwave::Label(len - 1, stop);
 // //	    labels->inSort (newmark);
 // //
 // //	    refresh ();
@@ -1161,7 +1176,7 @@ bool MainWidget::labelProperties(Label &label)
 // //void MainWidget::markPeriods (const char *str)
 // //{
 // //    if (signalmanage) {
-// //	Parser parser (str);
+// //	Kwave::Parser parser (str);
 // //
 // //	int high = signalmanage->getRate() / parser.toInt();
 // //	int low = signalmanage->getRate() / parser.toInt();
@@ -1173,7 +1188,7 @@ bool MainWidget::labelProperties(Label &label)
 // //
 // //	if (octave) for (int i = 0; i < AUTOKORRWIN; i++) weighttable[i] = 1;    //initialise moving weight table
 // //
-// //	Label *newmark;
+// //	Kwave::Label *newmark;
 // //	int next;
 // //	int len = signalmanage->getLength();
 // //	int *sam = signalmanage->getSignal(0)->getSample();    // ### @@@ ###
@@ -1184,7 +1199,7 @@ bool MainWidget::labelProperties(Label &label)
 // //	if (dialog) {
 // //	    dialog->show();
 // //
-// //	    newmark = new Label(cnt, start);
+// //	    newmark = new Kwave::Label(cnt, start);
 // //	    labels->inSort (newmark);
 // //
 // //	    while (cnt < len - 2*AUTOKORRWIN) {
@@ -1194,7 +1209,7 @@ bool MainWidget::labelProperties(Label &label)
 // //		    next = findNextRepeat (&sam[cnt], high);
 // //
 // //		if ((next < low) && (next > high)) {
-// //		    newmark = new Label(cnt, start);
+// //		    newmark = new Kwave::Label(cnt, start);
 // //
 // //		    labels->inSort (newmark);
 // //		}
