@@ -18,30 +18,32 @@
 #include "config.h"
 #include "math.h"
 
-#include <QMutableListIterator>
-#include <QColor>
-#include <QPainter>
+#include <QtCore/QMutableListIterator>
+#include <QtGui/QColor>
+#include <QtGui/QPainter>
 
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/Sample.h"
 #include "libkwave/SampleReader.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 #include "libkwave/Track.h"
 
-#include "OverViewCache.h"
+#include "libgui/OverViewCache.h"
 
-#define CACHE_SIZE 8192           /* number of cache entries */
+#define CACHE_SIZE 8192           /**< number of cache entries */
 
 //***************************************************************************
-OverViewCache::OverViewCache(SignalManager &signal, sample_index_t src_offset,
-                             sample_index_t src_length,
-                             const QList<unsigned int> *src_tracks)
+Kwave::OverViewCache::OverViewCache(Kwave::SignalManager &signal,
+                                    sample_index_t src_offset,
+                                    sample_index_t src_length,
+                                    const QList<unsigned int> *src_tracks)
     :m_signal(signal), m_min(), m_max(), m_state(), m_count(0), m_scale(1),
      m_lock(QMutex::Recursive), m_src_offset(src_offset),
      m_src_length(src_length), m_src_tracks(), m_src_deleted()
 {
     // connect to the signal manager
-    SignalManager *sig = &signal;
+    Kwave::SignalManager *sig = &signal;
     Q_ASSERT(sig);
     connect(sig, SIGNAL(sigTrackInserted(unsigned int, Kwave::Track *)),
             this, SLOT(slotTrackInserted(unsigned int, Kwave::Track *)));
@@ -76,7 +78,7 @@ OverViewCache::OverViewCache(SignalManager &signal, sample_index_t src_offset,
 }
 
 //***************************************************************************
-OverViewCache::~OverViewCache()
+Kwave::OverViewCache::~OverViewCache()
 {
     QMutexLocker lock(&m_lock);
 
@@ -86,13 +88,13 @@ OverViewCache::~OverViewCache()
 }
 
 //***************************************************************************
-sample_index_t OverViewCache::sourceLength()
+sample_index_t Kwave::OverViewCache::sourceLength()
 {
     return (m_src_length) ? m_src_length : m_signal.length();
 }
 
 //***************************************************************************
-void OverViewCache::scaleUp()
+void Kwave::OverViewCache::scaleUp()
 {
     QMutexLocker lock(&m_lock);
 
@@ -158,7 +160,7 @@ void OverViewCache::scaleUp()
 }
 
 //***************************************************************************
-void OverViewCache::scaleDown()
+void Kwave::OverViewCache::scaleDown()
 {
     QMutexLocker lock(&m_lock);
 
@@ -175,7 +177,7 @@ void OverViewCache::scaleDown()
 }
 
 //***************************************************************************
-int OverViewCache::trackIndex(unsigned int track_nr)
+int Kwave::OverViewCache::trackIndex(unsigned int track_nr)
 {
     QMutexLocker lock(&m_lock);
 
@@ -187,8 +189,9 @@ int OverViewCache::trackIndex(unsigned int track_nr)
 }
 
 //***************************************************************************
-void OverViewCache::invalidateCache(unsigned int track, unsigned int first,
-                                    unsigned int last)
+void Kwave::OverViewCache::invalidateCache(unsigned int track,
+                                           unsigned int first,
+                                           unsigned int last)
 {
     QMutexLocker lock(&m_lock);
 
@@ -208,7 +211,7 @@ void OverViewCache::invalidateCache(unsigned int track, unsigned int first,
 }
 
 //***************************************************************************
-void OverViewCache::slotTrackInserted(unsigned int index, Kwave::Track *)
+void Kwave::OverViewCache::slotTrackInserted(unsigned int index, Kwave::Track *)
 {
     QMutexLocker lock(&m_lock);
 
@@ -271,7 +274,7 @@ void OverViewCache::slotTrackInserted(unsigned int index, Kwave::Track *)
 }
 
 //***************************************************************************
-void OverViewCache::slotTrackDeleted(unsigned int index)
+void Kwave::OverViewCache::slotTrackDeleted(unsigned int index)
 {
     QMutexLocker lock(&m_lock);
 
@@ -306,8 +309,9 @@ void OverViewCache::slotTrackDeleted(unsigned int index)
 }
 
 //***************************************************************************
-void OverViewCache::slotSamplesInserted(unsigned int track,
-    sample_index_t offset, sample_index_t length)
+void Kwave::OverViewCache::slotSamplesInserted(unsigned int track,
+                                               sample_index_t offset,
+                                               sample_index_t length)
 {
     QMutexLocker lock(&m_lock);
 
@@ -339,8 +343,9 @@ void OverViewCache::slotSamplesInserted(unsigned int track,
 }
 
 //***************************************************************************
-void OverViewCache::slotSamplesDeleted(unsigned int track,
-    sample_index_t offset, sample_index_t length)
+void Kwave::OverViewCache::slotSamplesDeleted(unsigned int track,
+                                              sample_index_t offset,
+                                              sample_index_t length)
 {
     QMutexLocker lock(&m_lock);
 
@@ -385,8 +390,9 @@ void OverViewCache::slotSamplesDeleted(unsigned int track,
 }
 
 //***************************************************************************
-void OverViewCache::slotSamplesModified(unsigned int track,
-    sample_index_t offset, sample_index_t length)
+void Kwave::OverViewCache::slotSamplesModified(unsigned int track,
+                                               sample_index_t offset,
+                                               sample_index_t length)
 {
     QMutexLocker lock(&m_lock);
 
@@ -416,9 +422,9 @@ void OverViewCache::slotSamplesModified(unsigned int track,
 }
 
 //***************************************************************************
-QImage OverViewCache::getOverView(int width, int height,
-                                  const QColor &fg, const QColor &bg,
-                                  double gain)
+QImage Kwave::OverViewCache::getOverView(int width, int height,
+                                         const QColor &fg, const QColor &bg,
+                                         double gain)
 {
     QMutexLocker lock(&m_lock);
 
@@ -444,7 +450,7 @@ QImage OverViewCache::getOverView(int width, int height,
 	track_list = m_signal.allTracks();
     }
 
-    MultiTrackReader src(Kwave::SinglePassForward,
+    Kwave::MultiTrackReader src(Kwave::SinglePassForward,
 	m_signal, track_list, m_src_offset,
 	m_src_offset + length - 1);
     Q_ASSERT(m_min.count() == m_max.count());
@@ -465,7 +471,7 @@ QImage OverViewCache::getOverView(int width, int height,
 	sample_t *min = m_min[t].data();
 	sample_t *max = m_max[t].data();
 	CacheState *state = m_state[t].data();
-	SampleReader *reader = src[t];
+	Kwave::SampleReader *reader = src[t];
 	Q_ASSERT(reader);
 	if (!reader) continue;
 
@@ -548,15 +554,15 @@ QImage OverViewCache::getOverView(int width, int height,
 }
 
 //***************************************************************************
-void OverViewCache::dumpTracks()
+void Kwave::OverViewCache::dumpTracks()
 {
-    QString list = "OverViewCache - selected:";
+    QString list = _("OverViewCache - selected:");
     foreach (unsigned int track, m_src_tracks)
-	list += " " + list.number(track);
-    list += " --- deleted:";
+	list += _(" ") + list.number(track);
+    list += _(" --- deleted:");
     foreach (unsigned int track, m_src_deleted)
-	list += " " + list.number(track);
-    qDebug("%s", list.toLocal8Bit().data());
+	list += _(" ") + list.number(track);
+    qDebug("%s", DBG(list));
 }
 
 //***************************************************************************
