@@ -19,30 +19,30 @@
 
 #include <math.h>
 
-#include <QApplication>
-#include <QBitmap>
-#include <QBrush>
-#include <QEvent>
-#include <QMimeData>
-#include <QMouseEvent>
-#include <QPainter>
-#include <QThread>
-#include <QToolTip>
-#include <QUrl>
+#include <QtGui/QApplication>
+#include <QtGui/QBitmap>
+#include <QtGui/QBrush>
+#include <QtCore/QEvent>
+#include <QtCore/QMimeData>
+#include <QtGui/QMouseEvent>
+#include <QtGui/QPainter>
+#include <QtCore/QThread>
+#include <QtGui/QToolTip>
+#include <QtCore/QUrl>
 
 #include <kglobalsettings.h>
 
 #include "libkwave/CodecManager.h"
-#include "libkwave/KwaveDrag.h"
-#include "libkwave/KwaveFileDrag.h"
+#include "libkwave/Drag.h"
+#include "libkwave/FileDrag.h"
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/SignalManager.h"
+#include "libkwave/String.h"
 #include "libkwave/Utils.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
 
 #include "libgui/MouseMark.h"
-
-#include "SignalView.h"
+#include "libgui/SignalView.h"
 
 /** number of milliseconds until the position widget disappears */
 #define POSITION_WIDGET_TIME 5000
@@ -50,7 +50,7 @@
 //***************************************************************************
 //***************************************************************************
 Kwave::SignalView::SignalView(QWidget *parent, QWidget *controls,
-                              SignalManager *signal_manager,
+                              Kwave::SignalManager *signal_manager,
                               Location preferred_location,
                               int track)
     :QWidget(parent),
@@ -407,7 +407,8 @@ void Kwave::SignalView::mouseMoveEvent(QMouseEvent *e)
 	    if (description.length()) {
 		QString hms = Kwave::ms2hms(samples2ms(position));
 		QString txt =
-		    QString("%1\n%2\n%3").arg(description).arg(position).arg(hms);
+		    QString(_("%1\n%2\n%3")).arg(description
+			).arg(position).arg(hms);
 
 		showPosition(txt, position, mouse_pos);
 	    }
@@ -615,7 +616,7 @@ void Kwave::SignalView::startDragging()
     const sample_index_t length = m_signal_manager->selection().length();
     if (!length) return;
 
-    KwaveDrag *d = new KwaveDrag(this);
+    Kwave::Drag *d = new Kwave::Drag(this);
     Q_ASSERT(d);
     if (!d) return;
 
@@ -624,13 +625,13 @@ void Kwave::SignalView::startDragging()
     const double         rate  = m_signal_manager->rate();
     const unsigned int   bits  = m_signal_manager->bits();
 
-    MultiTrackReader src(Kwave::SinglePassForward, *m_signal_manager,
+    Kwave::MultiTrackReader src(Kwave::SinglePassForward, *m_signal_manager,
 	m_signal_manager->selectedTracks(), first, last);
 
     // create the file info
     Kwave::MetaDataList meta = m_signal_manager->metaData().selectByTracks(
 	m_signal_manager->selectedTracks());
-    FileInfo info(meta);
+    Kwave::FileInfo info(meta);
     info.setLength(last - first + 1);
     info.setRate(rate);
     info.setBits(bits);
@@ -643,7 +644,7 @@ void Kwave::SignalView::startDragging()
     }
 
     // start drag&drop, mode is determined automatically
-    UndoTransactionGuard undo(*m_signal_manager, i18n("Drag and Drop"));
+    Kwave::UndoTransactionGuard undo(*m_signal_manager, i18n("Drag and Drop"));
     Qt::DropAction drop = d->exec(Qt::CopyAction | Qt::MoveAction);
 
     if (drop == Qt::MoveAction) {
@@ -674,7 +675,7 @@ void Kwave::SignalView::dragEnterEvent(QDragEnterEvent *event)
         (event->proposedAction() != Qt::CopyAction))
         return; /* unsupported action */
 
-    if (KwaveFileDrag::canDecode(event->mimeData()))
+    if (Kwave::FileDrag::canDecode(event->mimeData()))
 	event->acceptProposedAction();
 }
 
@@ -693,12 +694,13 @@ void Kwave::SignalView::dropEvent(QDropEvent *event)
     Q_ASSERT(m_signal_manager);
     if (!m_signal_manager) return;
 
-    if (KwaveDrag::canDecode(event->mimeData())) {
-	UndoTransactionGuard undo(*m_signal_manager, i18n("Drag and Drop"));
+    if (Kwave::Drag::canDecode(event->mimeData())) {
+	Kwave::UndoTransactionGuard undo(*m_signal_manager,
+	                                 i18n("Drag and Drop"));
 	sample_index_t pos = m_offset + pixels2samples(event->pos().x());
 	sample_index_t len = 0;
 
-	if ((len = KwaveDrag::decode(this, event->mimeData(),
+	if ((len = Kwave::Drag::decode(this, event->mimeData(),
 	    *m_signal_manager, pos)))
 	{
 	    // set selection to the new area where the drop was done
@@ -712,15 +714,15 @@ void Kwave::SignalView::dropEvent(QDropEvent *event)
 	bool first = true;
 	foreach (QUrl url, event->mimeData()->urls()) {
 	    QString filename = url.toLocalFile();
-	    QString mimetype = CodecManager::whatContains(filename);
-	    if (CodecManager::canDecode(mimetype)) {
+	    QString mimetype = Kwave::CodecManager::whatContains(filename);
+	    if (Kwave::CodecManager::canDecode(mimetype)) {
 		if (first) {
 		    // first dropped URL -> open in this window
-		    emit sigCommand("open(" + filename + ")");
+		    emit sigCommand(_("open(") + filename + _(")"));
 		    first = false;
 		} else {
 		    // all others -> open a new window
-		    emit sigCommand("newwindow(" + filename + ")");
+		    emit sigCommand(_("newwindow(") + filename + _(")"));
 		}
 	    }
 	}
@@ -767,11 +769,11 @@ void Kwave::SignalView::dragMoveEvent(QDragMoveEvent* event)
 	r.setLeft(left);
 	r.setRight(right);
 	event->ignore(r);
-    } else if (KwaveDrag::canDecode(event->mimeData())) {
+    } else if (Kwave::Drag::canDecode(event->mimeData())) {
 	// accept if it is decodeable within the
 	// current range (if it's outside our own selection)
 	event->acceptProposedAction();
-    } else if (KwaveFileDrag::canDecode(event->mimeData())) {
+    } else if (Kwave::FileDrag::canDecode(event->mimeData())) {
 	// file drag
 	event->accept();
     } else event->ignore();
