@@ -19,10 +19,10 @@
 
 #include <math.h>
 
-#include <QMutexLocker>
-#include <QPainter>
-#include <QPolygon>
-#include <QTime>
+#include <QtCore/QMutexLocker>
+#include <QtGui/QPainter>
+#include <QtGui/QPolygon>
+#include <QtCore/QTime>
 
 #include "libkwave/SampleReader.h"
 #include "libkwave/Track.h"
@@ -281,7 +281,7 @@ bool Kwave::TrackPixmap::validateBuffer()
     int last = 0;
     int buflen = m_valid.size();
 
-    SampleReader *reader = m_track.openSampleReader(
+    Kwave::SampleReader *reader = m_track.openSampleReader(
 	Kwave::SinglePassForward, m_offset, m_track.length() - 1);
     Q_ASSERT(reader);
     if (!reader) return false;
