@@ -22,17 +22,17 @@
 
 #include <math.h>
 
-#include <QBitArray>
-#include <QColor>
-#include <QMutex>
-#include <QObject>
-#include <QPixmap>
-#include <QVector>
+#include <QtCore/QBitArray>
+#include <QtGui/QColor>
+#include <QtCore/QMutex>
+#include <QtCore/QObject>
+#include <QtGui/QPixmap>
+#include <QtCore/QVector>
 
 #include <kdemacros.h>
 
 #include "libkwave/Sample.h"
-#include "libkwave/KwaveSampleArray.h"
+#include "libkwave/SampleArray.h"
 
 /**
  * The TrackPixmap is a graphical representation of a track's sample
@@ -387,3 +387,6 @@ namespace Kwave
 }
 
 #endif /* _TRACK_PIXMAP_H_ */
+
+//***************************************************************************
+//***************************************************************************
