@@ -39,25 +39,27 @@
 #include <math.h>
 #include <errno.h>
 
-#include <QString>
-#include <QtGlobal>
+#include <QtCore/QLatin1Char>
+#include <QtCore/QString>
+#include <QtCore/QtGlobal>
 
 #include <klocale.h>
 
-#include "libkwave/CompressionType.h"
+#include "libkwave/Compression.h"
 #include "libkwave/memcpy.h"
+#include "libkwave/SampleEncoderLinear.h"
 #include "libkwave/SampleFormat.h"
+#include "libkwave/String.h"
 
 #include "PlayBack-ALSA.h"
-#include "SampleEncoderLinear.h"
 
-QMap<QString, QString> PlayBackALSA::m_device_list;
+QMap<QString, QString> Kwave::PlayBackALSA::m_device_list;
 
 /** gui name of the default device */
-#define DEFAULT_DEVICE (i18n("Default device") + QString("|sound_note"))
+#define DEFAULT_DEVICE (i18n("Default device") + _("|sound_note"))
 
 /** gui name of the null device */
-#define NULL_DEVICE (i18n("Null device") + QString("|sound_note"))
+#define NULL_DEVICE (i18n("Null device") + _("|sound_note"))
 
 //***************************************************************************
 
@@ -129,37 +131,37 @@ static const snd_pcm_format_t _known_formats[] =
 
 //***************************************************************************
 /** find out the SampleFormat of an ALSA format */
-static SampleFormat sample_format_of(snd_pcm_format_t fmt)
+static Kwave::SampleFormat sample_format_of(snd_pcm_format_t fmt)
 {
     if (snd_pcm_format_float(fmt)) {
 	if (snd_pcm_format_width(fmt) == 32)
-	    return SampleFormat::Float;
+	    return Kwave::SampleFormat::Float;
 	if (snd_pcm_format_width(fmt) == 64)
-	    return SampleFormat::Double;
+	    return Kwave::SampleFormat::Double;
     } else if (snd_pcm_format_linear(fmt)) {
 	if (snd_pcm_format_signed(fmt) == 1)
-	    return SampleFormat::Signed;
+	    return Kwave::SampleFormat::Signed;
 	else if (snd_pcm_format_unsigned(fmt) == 1)
-	    return SampleFormat::Unsigned;
+	    return Kwave::SampleFormat::Unsigned;
     }
 
-    return SampleFormat::Unknown;
+    return Kwave::SampleFormat::Unknown;
 }
 
 //***************************************************************************
 /** find out the endianness of an ALSA format */
-static byte_order_t endian_of(snd_pcm_format_t fmt)
+static Kwave::byte_order_t endian_of(snd_pcm_format_t fmt)
 {
     if (snd_pcm_format_little_endian(fmt) == 1)
-	return LittleEndian;
+	return Kwave::LittleEndian;
     if (snd_pcm_format_big_endian(fmt) == 1)
-	return BigEndian;
-    return CpuEndian;
+	return Kwave::BigEndian;
+    return Kwave::CpuEndian;
 }
 
 //***************************************************************************
-PlayBackALSA::PlayBackALSA()
-    :PlayBackDevice(),
+Kwave::PlayBackALSA::PlayBackALSA()
+    :Kwave::PlayBackDevice(),
     m_device_name(),
     m_handle(0),
     m_rate(0),
@@ -178,13 +180,14 @@ PlayBackALSA::PlayBackALSA()
 }
 
 //***************************************************************************
-PlayBackALSA::~PlayBackALSA()
+Kwave::PlayBackALSA::~PlayBackALSA()
 {
     close();
 }
 
 //***************************************************************************
-int PlayBackALSA::setFormat(snd_pcm_hw_params_t *hw_params, unsigned int bits)
+int Kwave::PlayBackALSA::setFormat(snd_pcm_hw_params_t *hw_params,
+                                   unsigned int bits)
 {
     qDebug("PlayBackALSA::setFormat(..., bits=%u)", bits);
     m_format = SND_PCM_FORMAT_UNKNOWN;
@@ -205,7 +208,7 @@ int PlayBackALSA::setFormat(snd_pcm_hw_params_t *hw_params, unsigned int bits)
     m_bytes_per_sample =
 	((snd_pcm_format_physical_width(m_format) + 7) >> 3) * m_channels;
 
-    m_encoder = new SampleEncoderLinear(
+    m_encoder = new Kwave::SampleEncoderLinear(
 	sample_format_of(m_format),
 	m_bits,
 	endian_of(m_format)
@@ -227,7 +230,7 @@ int PlayBackALSA::setFormat(snd_pcm_hw_params_t *hw_params, unsigned int bits)
 }
 
 //***************************************************************************
-int PlayBackALSA::mode2format(int bits)
+int Kwave::PlayBackALSA::mode2format(int bits)
 {
     // loop over all supported formats and keep only those that are
     // compatible with the given compression, bits and sample format
@@ -249,7 +252,7 @@ int PlayBackALSA::mode2format(int bits)
 }
 
 //***************************************************************************
-QList<int> PlayBackALSA::detectSupportedFormats(const QString &device)
+QList<int> Kwave::PlayBackALSA::detectSupportedFormats(const QString &device)
 {
     // start with an empty list
     QList<int> supported_formats;
@@ -290,17 +293,17 @@ QList<int> PlayBackALSA::detectSupportedFormats(const QString &device)
 	}
 	if (!fmt) continue;
 
-// 	CompressionType t;
-// 	SampleFormat::Map sf;
+// 	Kwave::Compression t;
+// 	Kwave::SampleFormat::Map sf;
 // 	qDebug("#%2u, %2d, %2u bit [%u byte], %s, '%s'",
 // 	    i,
 // 	    *fmt,
 // 	    snd_pcm_format_width(*fmt),
 // 	    (snd_pcm_format_physical_width(*fmt)+7) >> 3,
-// 	    endian_of(*fmt) == CpuEndian ? "CPU" :
-// 	    (endian_of(*fmt) == LittleEndian ? "LE " : "BE "),
-// 	    sf.name(sf.findFromData(sample_format_of(
-// 		*fmt))).local8Bit().data());
+// 	    endian_of(*fmt) == Kwave::CpuEndian ? "CPU" :
+// 	    (endian_of(*fmt) == Kwave::LittleEndian ? "LE " : "BE "),
+// 	    sf.description(sf.findFromData(sample_format_of(
+// 		*fmt), true)).local8Bit().data());
 
 	supported_formats.append(i);
     }
@@ -311,8 +314,8 @@ QList<int> PlayBackALSA::detectSupportedFormats(const QString &device)
 }
 
 //***************************************************************************
-int PlayBackALSA::openDevice(const QString &device, unsigned int rate,
-                             unsigned int channels, unsigned int bits)
+int Kwave::PlayBackALSA::openDevice(const QString &device, unsigned int rate,
+                                    unsigned int channels, unsigned int bits)
 {
     int err;
     snd_output_t *output = NULL;
@@ -334,17 +337,14 @@ int PlayBackALSA::openDevice(const QString &device, unsigned int rate,
 
     // translate verbose name to internal ALSA name
     QString alsa_device = alsaDeviceName(device);
-    qDebug("PlayBackALSA::openDevice() - opening ALSA device '%s', "\
+    qDebug("PlayBackALSA::openDevice() - opening ALSA device '%s', "
            "%dHz %d channels, %u bit",
-           alsa_device.toLocal8Bit().data(), rate, channels, bits);
+           DBG(alsa_device.split(_("|")).at(0)), rate, channels, bits);
 
     // workaround for bug in ALSA
     // if the device name ends with "," -> invalid name
-    if (alsa_device.endsWith(",")) return -ENODEV;
+    if (alsa_device.endsWith(_(","))) return -ENODEV;
 
-    Q_ASSERT(rate);
-    Q_ASSERT(channels);
-    Q_ASSERT(bits);
     if (!rate) return -EINVAL;
     if (!channels) return -EINVAL;
     if (!bits) return -EINVAL;
@@ -526,13 +526,12 @@ int PlayBackALSA::openDevice(const QString &device, unsigned int rate,
 }
 
 //***************************************************************************
-QString PlayBackALSA::open(const QString &device, double rate,
-                           unsigned int channels, unsigned int bits,
-                           unsigned int bufbase)
+QString Kwave::PlayBackALSA::open(const QString &device, double rate,
+                                  unsigned int channels, unsigned int bits,
+                                  unsigned int bufbase)
 {
-    qDebug("PlayBackALSA::open(device=%s,rate=%0.1f,channels=%u,"\
-	"bits=%u, bufbase=%u)", device.toLocal8Bit().data(), rate, channels,
-	bits, bufbase);
+    qDebug("PlayBackALSA::open(device=%s,rate=%0.1f,channels=%u, bits=%u, "
+           "bufbase=%u)", DBG(device), rate, channels, bits, bufbase);
 
     m_device_name = device;
     m_rate        = rate;
@@ -576,7 +575,7 @@ QString PlayBackALSA::open(const QString &device, double rate,
 		break;
 	    default:
 		reason = i18n("Opening the device '%1' failed: %2",
-	            device.section('|',0,0),
+	            device.section(QLatin1Char('|'), 0, 0),
 		    QString::fromLocal8Bit(snd_strerror(err)));
 	}
 	return reason;
@@ -587,7 +586,7 @@ QString PlayBackALSA::open(const QString &device, double rate,
     Q_ASSERT(m_bytes_per_sample);
     unsigned int chunk_bytes = m_chunk_size * m_bytes_per_sample;
     Q_ASSERT(chunk_bytes);
-    if (!chunk_bytes) return 0;
+    if (!chunk_bytes) return QString();
     unsigned int n = static_cast<unsigned int>(ceil(
 	static_cast<float>(1 << m_bufbase) /
 	static_cast<float>(chunk_bytes)));
@@ -599,11 +598,11 @@ QString PlayBackALSA::open(const QString &device, double rate,
 //     qDebug("PlayBackALSA::open: OK, buffer resized to %u bytes",
 //            m_buffer_size);
 
-    return 0;
+    return QString();
 }
 
 //***************************************************************************
-int PlayBackALSA::write(const Kwave::SampleArray &samples)
+int Kwave::PlayBackALSA::write(const Kwave::SampleArray &samples)
 {
     Q_ASSERT(m_encoder);
     if (!m_encoder) return -EIO;
@@ -629,7 +628,7 @@ int PlayBackALSA::write(const Kwave::SampleArray &samples)
 }
 
 //***************************************************************************
-int PlayBackALSA::flush()
+int Kwave::PlayBackALSA::flush()
 {
     if (!m_buffer_used) return 0; // nothing to do
     Q_ASSERT(m_channels);
@@ -642,7 +641,7 @@ int PlayBackALSA::flush()
 	unsigned int timeout = (m_rate > 0) ?
 	    3 * ((1000 * buffer_samples) /
 	    static_cast<unsigned int>(m_rate)) : 1000U;
-	u_int8_t *p = reinterpret_cast<u_int8_t *>(m_buffer.data());
+	quint8 *p = reinterpret_cast<quint8 *>(m_buffer.data());
 	int r;
 
 	// pad the buffer with silence if necessary
@@ -710,7 +709,7 @@ int PlayBackALSA::flush()
 }
 
 //***************************************************************************
-int PlayBackALSA::close()
+int Kwave::PlayBackALSA::close()
 {
     flush();
 
@@ -729,7 +728,7 @@ int PlayBackALSA::close()
 }
 
 //***************************************************************************
-void PlayBackALSA::scanDevices()
+void Kwave::PlayBackALSA::scanDevices()
 {
     snd_ctl_t *handle;
     int card, err, dev;
@@ -747,10 +746,10 @@ void PlayBackALSA::scanDevices()
 	return;
     }
 
-    qDebug("**** List of PLAYBACK Hardware Devices ****");
+//     qDebug("**** List of PLAYBACK Hardware Devices ****");
     while (card >= 0) {
 	QString name;
-	name = "hw:%1";
+	name = _("hw:%1");
 	name = name.arg(card);
 	if ((err = snd_ctl_open(&handle, name.toLocal8Bit().data(), 0)) < 0) {
 	    qWarning("control open (%i): %s", card, snd_strerror(err));
@@ -780,24 +779,24 @@ void PlayBackALSA::scanDevices()
 	    }
 	    count = snd_pcm_info_get_subdevices_count(pcminfo);
 
-	    qDebug("card %i: %s [%s], device %i: %s [%s]",
-		card,
-		snd_ctl_card_info_get_id(info),
-		snd_ctl_card_info_get_name(info),
-		dev,
-		snd_pcm_info_get_id(pcminfo),
-		snd_pcm_info_get_name(pcminfo));
+// 	    qDebug("card %i: %s [%s], device %i: %s [%s]",
+// 		card,
+// 		snd_ctl_card_info_get_id(info),
+// 		snd_ctl_card_info_get_name(info),
+// 		dev,
+// 		snd_pcm_info_get_id(pcminfo),
+// 		snd_pcm_info_get_name(pcminfo));
 
 	    // add the device to the list
 	    QString hw_device;
-	    hw_device = "plughw:%1,%2";
+	    hw_device = _("plughw:%1,%2");
 	    hw_device = hw_device.arg(card).arg(dev);
 
-	    QString card_name   = snd_ctl_card_info_get_name(info);
-	    QString device_name = snd_pcm_info_get_name(pcminfo);
+	    QString card_name   = _(snd_ctl_card_info_get_name(info));
+	    QString device_name = _(snd_pcm_info_get_name(pcminfo));
 
- 	    qDebug("  Subdevices: %i/%i\n",
-		snd_pcm_info_get_subdevices_avail(pcminfo), count);
+//  	    qDebug("  Subdevices: %i/%i\n",
+// 		snd_pcm_info_get_subdevices_avail(pcminfo), count);
 	    if (count > 1) {
 		for (idx = 0; idx < static_cast<int>(count); idx++) {
 		    snd_pcm_info_set_subdevice(pcminfo, idx);
@@ -805,20 +804,18 @@ void PlayBackALSA::scanDevices()
 			qWarning("ctrl digital audio playback info (%i): %s",
 			         card, snd_strerror(err));
 		    } else {
-			QString hwdev = hw_device + QString(",%1").arg(idx);
+			QString hwdev = hw_device + _(",%1").arg(idx);
 			QString subdevice_name =
-			    snd_pcm_info_get_subdevice_name(pcminfo);
+			    _(snd_pcm_info_get_subdevice_name(pcminfo));
 			QString name = QString(
 			    i18n("Card %1: ", card) + card_name +
-			    "|sound_card||" +
+			    _("|sound_card||") +
 			    i18n("Device %1: ", dev) + device_name +
-			    "|sound_device||" +
+			    _("|sound_device||") +
 			    i18n("Subdevice %1: ", idx) + subdevice_name +
-			    "|sound_subdevice"
+			    _("|sound_subdevice")
 			);
-			qDebug("# '%s' -> '%s'",
-			    hwdev.toLocal8Bit().data(),
-			    name.toLocal8Bit().data());
+			qDebug("# '%s' -> '%s'", DBG(hwdev), DBG(name));
 			m_device_list.insert(name, hwdev);
 		    }
 		}
@@ -826,12 +823,11 @@ void PlayBackALSA::scanDevices()
 		// no sub-devices
 		QString name = QString(
 		    i18n("Card %1: ", card) +
-		         card_name + "|sound_card||" +
+		         card_name + _("|sound_card||") +
 		    i18n("Device %1: ", dev) +
-		          device_name + "|sound_subdevice"
+		          device_name + _("|sound_subdevice")
 		);
-		qDebug("# '%s' -> '%s'", hw_device.toLocal8Bit().data(),
-		    name.toLocal8Bit().data());
+// 		qDebug("# '%s' -> '%s'", DBG(hw_device), DBG(name));
 		m_device_list.insert(name, hw_device);
 	    }
 	}
@@ -846,17 +842,18 @@ next_card:
     // per default: offer the dmix plugin and the default device
     // if slave devices exist
     if (!m_device_list.isEmpty()) {
-        m_device_list.insert(i18n("DMIX plugin")+QString("|sound_note"),
-                             "plug:dmix");
-        m_device_list.insert(DEFAULT_DEVICE, "default");
+        m_device_list.insert(i18n("DMIX plugin") +
+                             _("|sound_note"),
+                             _("plug:dmix"));
+        m_device_list.insert(DEFAULT_DEVICE, _("default"));
     } else {
-        m_device_list.insert(NULL_DEVICE, "null");
+        m_device_list.insert(NULL_DEVICE, _("null"));
     }
 
 }
 
 //***************************************************************************
-QString PlayBackALSA::alsaDeviceName(const QString &name)
+QString Kwave::PlayBackALSA::alsaDeviceName(const QString &name)
 {
     if (m_device_list.isEmpty() || (name.length() &&
         !m_device_list.contains(name)))
@@ -871,15 +868,14 @@ QString PlayBackALSA::alsaDeviceName(const QString &name)
 	foreach (QString n, m_device_list.values())
 	    if (n == name) return n;
 
-	qWarning("PlayBackALSA::alsaDeviceName('%s') - NOT FOUND",
-	    name.toLocal8Bit().data());
-	return "";
+	qWarning("PlayBackALSA::alsaDeviceName('%s') - NOT FOUND", DBG(name));
+	return _("");
     }
     return m_device_list[name];
 }
 
 //***************************************************************************
-QStringList PlayBackALSA::supportedDevices()
+QStringList Kwave::PlayBackALSA::supportedDevices()
 {
     // re-validate the list if necessary
     scanDevices();
@@ -892,19 +888,19 @@ QStringList PlayBackALSA::supportedDevices()
     if (list.contains(DEFAULT_DEVICE))
 	list.move(list.indexOf(DEFAULT_DEVICE), 0);
 
-    if (!list.isEmpty()) list.append("#TREE#");
+    if (!list.isEmpty()) list.append(_("#TREE#"));
 
     return list;
 }
 
 //***************************************************************************
-QString PlayBackALSA::fileFilter()
+QString Kwave::PlayBackALSA::fileFilter()
 {
-    return "";
+    return _("");
 }
 
 //***************************************************************************
-snd_pcm_t *PlayBackALSA::openDevice(const QString &device)
+snd_pcm_t *Kwave::PlayBackALSA::openDevice(const QString &device)
 {
     snd_pcm_t *pcm = m_handle;
 
@@ -917,7 +913,7 @@ snd_pcm_t *PlayBackALSA::openDevice(const QString &device)
 
     // workaround for bug in ALSA
     // if the device name ends with "," -> invalid name
-    if (alsa_device.endsWith(",")) return 0;
+    if (alsa_device.endsWith(_(","))) return 0;
 
     if (!pcm) {
 	// open the device in case it's not already open
@@ -926,10 +922,8 @@ snd_pcm_t *PlayBackALSA::openDevice(const QString &device)
 	                       SND_PCM_NONBLOCK);
 	if (err < 0) {
 	    pcm = 0;
-	    qWarning("PlayBackALSA::openDevice('%s') - "\
-	             "failed, err=%d (%s)",
-	             alsa_device.toLocal8Bit().data(),
-	             err, snd_strerror(err));
+	    qWarning("PlayBackALSA::openDevice('%s') - failed, err=%d (%s)",
+	             DBG(alsa_device), err, snd_strerror(err));
 	}
     }
 
@@ -937,7 +931,7 @@ snd_pcm_t *PlayBackALSA::openDevice(const QString &device)
 }
 
 //***************************************************************************
-QList<unsigned int> PlayBackALSA::supportedBits(const QString &device)
+QList<unsigned int> Kwave::PlayBackALSA::supportedBits(const QString &device)
 {
     QList<unsigned int> list;
     QList<int> supported_formats;
@@ -962,8 +956,8 @@ QList<unsigned int> PlayBackALSA::supportedBits(const QString &device)
 }
 
 //***************************************************************************
-int PlayBackALSA::detectChannels(const QString &device,
-                                 unsigned int &min, unsigned int &max)
+int Kwave::PlayBackALSA::detectChannels(const QString &device,
+                                        unsigned int &min, unsigned int &max)
 {
     min = max = 0;
     snd_pcm_hw_params_t *p;
