@@ -18,18 +18,17 @@
 #include "config.h"
 #include <errno.h>
 
-#include <QStringList>
+#include <QtCore/QStringList>
 
 #include <klocale.h>
 
-#include "libkwave/KwaveConnect.h"
+#include "libkwave/Connect.h"
 #include "libkwave/MultiTrackReader.h"
+#include "libkwave/MultiTrackSource.h"
 #include "libkwave/MultiTrackWriter.h"
-#include "libkwave/KwaveMultiTrackSource.h"
-#include "libkwave/Parser.h"
 #include "libkwave/PluginManager.h"
 #include "libkwave/SignalManager.h"
-#include "libkwave/modules/KwaveMul.h"
+#include "libkwave/modules/Mul.h"
 #include "libkwave/undo/UndoTransactionGuard.h"
 
 #include "libgui/OverViewCache.h"
@@ -37,22 +36,22 @@
 #include "VolumePlugin.h"
 #include "VolumeDialog.h"
 
-KWAVE_PLUGIN(VolumePlugin, "volume", "2.1",
+KWAVE_PLUGIN(Kwave::VolumePlugin, "volume", "2.3",
              I18N_NOOP("Volume"), "Thomas Eschenbacher");
 
 //***************************************************************************
-VolumePlugin::VolumePlugin(const PluginContext &context)
-    :Kwave::Plugin(context), m_params(), m_factor(1.0), m_mode(0)
+Kwave::VolumePlugin::VolumePlugin(Kwave::PluginManager &plugin_manager)
+    :Kwave::Plugin(plugin_manager), m_params(), m_factor(1.0), m_mode(0)
 {
 }
 
 //***************************************************************************
-VolumePlugin::~VolumePlugin()
+Kwave::VolumePlugin::~VolumePlugin()
 {
 }
 
 //***************************************************************************
-int VolumePlugin::interpreteParameters(QStringList &params)
+int Kwave::VolumePlugin::interpreteParameters(QStringList &params)
 {
     bool ok;
     QString param;
@@ -77,22 +76,23 @@ int VolumePlugin::interpreteParameters(QStringList &params)
 }
 
 //***************************************************************************
-QStringList *VolumePlugin::setup(QStringList &previous_params)
+QStringList *Kwave::VolumePlugin::setup(QStringList &previous_params)
 {
     // try to interprete the previous parameters
     interpreteParameters(previous_params);
 
     // initialize the overview cache
-    SignalManager &mgr = manager().signalManager();
+    Kwave::SignalManager &mgr = manager().signalManager();
     QList<unsigned int> tracks;
     sample_index_t first, last;
     sample_index_t length = selection(&tracks, &first, &last, true);
-    OverViewCache *overview_cache = new OverViewCache(mgr,
+    Kwave::OverViewCache *overview_cache = new Kwave::OverViewCache(mgr,
         first, length, tracks.isEmpty() ? 0 : &tracks);
     Q_ASSERT(overview_cache);
 
     // create the setup dialog
-    VolumeDialog *dialog = new VolumeDialog(parentWidget(), overview_cache);
+    Kwave::VolumeDialog *dialog =
+	new Kwave::VolumeDialog(parentWidget(), overview_cache);
     if (!dialog) {
 	if (overview_cache) delete overview_cache;
 	return 0;
@@ -119,7 +119,7 @@ QStringList *VolumePlugin::setup(QStringList &previous_params)
 }
 
 //***************************************************************************
-void VolumePlugin::run(QStringList params)
+void Kwave::VolumePlugin::run(QStringList params)
 {
     QList<unsigned int> tracks;
     sample_index_t first, last;
@@ -128,12 +128,12 @@ void VolumePlugin::run(QStringList params)
     if (!selection(&tracks, &first, &last, true) || tracks.isEmpty())
 	return;
 
-    UndoTransactionGuard undo_guard(*this, i18n("Volume"));
+    Kwave::UndoTransactionGuard undo_guard(*this, i18n("Volume"));
 
     // create all objects
-    MultiTrackReader source(Kwave::SinglePassForward,
+    Kwave::MultiTrackReader source(Kwave::SinglePassForward,
 	signalManager(), selectedTracks(), first, last);
-    Kwave::MultiTrackWriter sink(signalManager(), tracks, Overwrite,
+    Kwave::MultiTrackWriter sink(signalManager(), tracks, Kwave::Overwrite,
 	first, last);
     Kwave::MultiTrackSource<Kwave::Mul, true> mul(tracks.count());
 
